[mcclim-cvs] CVS mcclim/Drei/Tests

thenriksen thenriksen at common-lisp.net
Wed Aug 15 10:03:32 UTC 2007


Update of /project/mcclim/cvsroot/mcclim/Drei/Tests
In directory clnet:/tmp/cvs-serv25734/Drei/Tests

Modified Files:
	undo-tests.lisp testing.lisp rectangle-tests.lisp 
	motion-tests.lisp lisp-syntax-tests.lisp kill-ring-tests.lisp 
	editing-tests.lisp core-tests.lisp buffer-tests.lisp 
	buffer-streams-tests.lisp base-tests.lisp 
Log Message:
Revamped the Drei test suite infrastructure slightly.


--- /project/mcclim/cvsroot/mcclim/Drei/Tests/undo-tests.lisp	2006/12/04 07:54:51	1.1
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/undo-tests.lisp	2007/08/15 10:03:32	1.2
@@ -21,7 +21,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite undo-tests :description "The test suite for tests
-related to Drei's undo system.")
+related to Drei's undo system." :in drei-tests)
 
 (in-suite undo-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/rectangle-tests.lisp	2006/12/04 07:54:51	1.1
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/rectangle-tests.lisp	2007/08/15 10:03:32	1.2
@@ -21,7 +21,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite rectangle-tests :description "The test suite for
-rectangle-editing related tests.")
+rectangle-editing related tests." :in drei-tests)
 
 (in-suite rectangle-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/motion-tests.lisp	2007/04/27 21:37:15	1.3
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/motion-tests.lisp	2007/08/15 10:03:32	1.4
@@ -22,7 +22,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite motion-tests :description "The test suite for
-DREI-MOTION related tests.")
+DREI-MOTION related tests." :in drei-tests)
 
 (in-suite motion-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/lisp-syntax-tests.lisp	2007/08/13 21:58:43	1.5
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/lisp-syntax-tests.lisp	2007/08/15 10:03:32	1.6
@@ -25,7 +25,7 @@
 explicitly tested. Instead, it is hoped that any defects will be
 caught by other test cases, all of which depend on correct
 parsing. Also, redisplay is not tested, because no-one has any
-idea how to do it.")
+idea how to do it." :in drei-tests)
 
 (in-suite lisp-syntax-tests)
 
@@ -1797,6 +1797,7 @@
         ;; Also, as fun as infinite recursion would be... disable this
         ;; test before running the suite.
         (let ((*run-self-compilation-test* nil))
-          (format t "Re-running Drei test suite with newly evaluated Drei definitions~%")
-          (run-tests)))
+          (format *test-dribble* "~%Re-running Drei test suite with newly evaluated Drei definitions~%")
+          (is-true (results-status (let ((fiveam:*test-dribble* (make-broadcast-stream)))
+                                     (fiveam:run 'drei-tests))))))
       (skip "Sensibly skipping self-compilation test. Set DREI-TESTS:*RUN-SELF-COMPILATION-TEST* to true if you don't want to skip it")))
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/kill-ring-tests.lisp	2006/12/04 07:54:51	1.1
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/kill-ring-tests.lisp	2007/08/15 10:03:32	1.2
@@ -27,7 +27,7 @@
 (in-package :drei-tests)
 
 (def-suite kill-ring-tests :description "The test suite for DREI-KILL-RING
-related tests.")
+related tests." :in drei-tests)
 
 (in-suite kill-ring-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/editing-tests.lisp	2006/12/04 07:54:51	1.1
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/editing-tests.lisp	2007/08/15 10:03:32	1.2
@@ -23,7 +23,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite editing-tests :description "The test suite for
-DREI-EDITING related tests.")
+DREI-EDITING related tests." :in drei-tests)
 
 (in-suite editing-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/core-tests.lisp	2007/02/13 12:14:11	1.3
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/core-tests.lisp	2007/08/15 10:03:32	1.4
@@ -23,7 +23,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite core-tests :description "The test suite for
-DREI-CORE related tests.")
+DREI-CORE related tests." :in drei-tests)
 
 (in-suite core-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/buffer-tests.lisp	2006/12/04 07:54:51	1.1
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/buffer-tests.lisp	2007/08/15 10:03:32	1.2
@@ -28,7 +28,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite buffer-tests :description "The test suite for
-buffer-protocol related tests.")
+buffer-protocol related tests." :in drei-tests)
 
 (in-suite buffer-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/buffer-streams-tests.lisp	2007/01/15 11:35:53	1.1
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/buffer-streams-tests.lisp	2007/08/15 10:03:32	1.2
@@ -23,7 +23,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite buffer-streams-tests :description "The test suite for
-buffer-streams related tests.")
+buffer-streams related tests." :in drei-tests)
 
 (in-suite buffer-streams-tests)
 
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/base-tests.lisp	2007/02/13 12:14:11	1.2
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/base-tests.lisp	2007/08/15 10:03:32	1.3
@@ -26,7 +26,7 @@
 (cl:in-package :drei-tests)
 
 (def-suite base-tests :description "The test suite for DREI-BASE
-related tests.")
+related tests." :in drei-tests)
 
 (in-suite base-tests)
 




More information about the Mcclim-cvs mailing list
--- /project/mcclim/cvsroot/mcclim/Drei/Tests/testing.lisp	2007/02/17 17:54:06	1.4
+++ /project/mcclim/cvsroot/mcclim/Drei/Tests/testing.lisp	2007/08/15 10:03:32	1.5
@@ -23,7 +23,7 @@
 (cl:in-package :drei-tests)
 
 ;; Define some stuff to ease the pain of writing repetitive test
 ;; cases. Also provide test-running entry point.
 
 (defclass delegating-standard-buffer (delegating-buffer) ()
   (:default-initargs :implementation (make-instance 'standard-buffer)))
@@ -93,34 +93,11 @@
          (with-bound-drei-special-variables (,drei :minibuffer nil)
            , at body)))))
 
+(def-suite drei-tests :description "The test suite for all Drei
+test cases. Has nested test suites for the actual tests.")
+
 (defun run-tests ()
-  (format t "Testing buffer protocol implementation(s)~%")
-  (run! 'buffer-tests)
-  (format t "Testing basic functions~%")
-  (run! 'base-tests)
-  (format t "Testing the kill ring~%")
-  (run! 'kill-ring-tests)
-  (format t "Testing mark motion~%")
-  (run! 'motion-tests)
-  (format t "Testing text editing functions~%")
-  (run! 'editing-tests)
-  (format t "Testing miscellaneus editor functions~%")
-  (run! 'core-tests)
-  (format t "Testing buffer-based gray streams~%")
-  (run! 'buffer-streams-tests)
-  (format t "Testing rectangle editing~%")
-  (run! 'rectangle-tests)
-  (format t "Testing undo~%")
-  (run! 'undo-tests)
-  (format t "Testing the Lisp syntax module~%")
-  (run! 'lisp-syntax-tests)
-
-  (format t "Running the CL-AUTOMATON tests~%")
-  (format t "Testing regular expressions~%")
-  (run! 'regexp-tests)
-  (format t "Testing eqv-hash~%")
-  (run! 'eqv-hash-tests)
-  (format t "Testing states and transitions~%")
-  (run! 'state-and-transition-tests)
-  (format t "Testing core automata functions~%")
-  (run! 'automaton-tests))
+  "Run the Drei test suite. A dot will be printed for each passed
+test, a \"f\" for each failed test, a \"X\" for each test that
+causes an error, and an \"s\" for each skipped test."
+  (run! 'drei-tests))
@@ -23,7 +23,7 @@
 
 ;; Define some stuff to ease the pain of writing repetitive test
-;; cases. Also provide test-running entry point.
+;; cases. Also provide global test-suite and test-running entry point.
 
 (defclass delegating-standard-buffer (delegating-buffer) ()